local configUtil = require 'password.util'

function logQuery()
   -- call AUTH() to load Iguana credentials 
   local auth = AUTH()

   -- get current time and last hour to query all messages from the last hour
   local timeNow = os.date("*t")
   timeNow.hour = timeNow.hour - 1
   local lastHour = os.time(timeNow)
   lastHour = tostring(lastHour):gsub('-','/')

   -- call Log API
   local results = net.http.get{
      url=URL(),
      parameters={
         username= auth.username,
         password= auth.password,
         type    = 'messages',               -- of type message
         source  = 'LogAPI - HL7 Processor', -- from this source channel
         before  = os.date('%x %X'),         -- before date
         after   = lastHour,                 -- after date

         -- some other useful parameters:
         -- reverse = 'true',                -- with newest entries at the top
         -- limit     = 50,                  -- aggregate only 50 entries
         -- refmsgid  = 'messageId',         -- unique log message ID 
         -- filter    = 'VIP',               -- only messages containing "VIP"
         -- deleted   = 'false',             -- exclude deleted messages
         -- debugmode = 'false'              -- exclude debug messages
      },live=true} 
  
      return results 
end 







-- Local functions -- 
function URL()
   local T = iguana.webInfo()
   local URL = 'http://'..T.ip..':'..T.web_config.port..'/api_query'
   return URL
end 

-- Use Encrypt Password Utility to secure credentials
-- https://help.interfaceware.com/v6/encrypted-password-utility
function AUTH() 
   -- When running for the first time: 
   -- 1) Go to password.configs.lua shared module to add/update configs starting at line10
   -- 2) Initialize configuration value ONCE.
   -- 2.1) Edit 'username' and 'password' values on line51 and 52
   -- 2.2) Then uncomment the lines and run script to update stored values
   -- 3.3) Then re comment the lines out
   --configUtil.save(configs.APP_USERNAME, 'admin')
   --configUtil.save(configs.APP_PASSWORD, 'password')
   local configs = configUtil.configs
   local creds = {
      username = configUtil.load(configs.APP_USERNAME), 
      password = configUtil.load(configs.APP_PASSWORD)}
   return creds
end 