------------------------------------------------------------------------------------
-- This channel runs hourly, calling Iguana's Log API to query for all message 
-- logs from the past hour. The result messages are parsed and written to a txt 
-- file for archiving or future resbmission if required (the HL7 Simluator, 
-- located in the working directory, can be used to resubmit messages via LLP). 
-- https://help.interfaceware.com/v6/http-api-reference#log

-- Directions:
-- (1) In the From Translator settings, set the poll time to 3600000ms to run hourly.
-- (2) In logQuery.lua, please follow steps to use the Encrypted Password Utility.  
-- (3) In logQuery.lua, please modify the source parameter with the channel you 
--     want to query.
-- (4) If required, change the archive directory location on line33 of main.lua. 
--     Default configuration creates a file in the Iguana working directory.
------------------------------------------------------------------------------------

require 'logQuery'

function main()
   
   -- (1) Call Log API to get logs from the past hour
   local hourlyLogs = logQuery()
   
   -- (2) Parse results to save messages only
   local results = xml.parse{data=hourlyLogs}
	
   -- (3) Loop through messages and archive to file
   for i=1, results.export:childCount("message") do 
      
      -- clean up msg and add HL7 message EOL for resubmission
      local cleanMsg = results.export:child('message',i).data:gsub('&#xD;', '\r')      
      trace(cleanMsg)
      
      -- (4) Archive messages in Iguana working directory 
      -- define directory and file
      local archive = iguana.workingDir()
      local filename = os.date('%Y%m%d')..'.txt'

      -- open file in append mode
      local file = io.open(archive..filename, 'a')
      -- write logs to directory
      file:write(cleanMsg..'\r')
      file:close()
   
   end

end

